from typing import Literal, Optional
from pydantic import BaseModel


class ShoppingLocation(BaseModel):
    """"
    A classe representing an interesting area for shopping.
    
    It can represent either a general area or a specifc route with start and end point.
    The importance represents the number of shops found in this cluster.
    
    Attributes:
        type :       either a 'street' or 'area' (representing a denser field of shops).
        importance : size of the cluster (number of points).
        centroid :   center of the cluster.
        start :      if the type is a street it goes from here...
        end :        ...to here
    """
    type: Literal['street', 'area']
    importance: int
    centroid: tuple
    start: Optional[list] = None
    end: Optional[list] = None